@@ -119,6 +119,7 @@ static unsigned int FUNCTYPE
 SCALC (register number_t zre, register number_t zim, register number_t pre,
        register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        SCALC (register number_t zre, register number_t zim,
 	      register number_t pre, register number_t pim)
@@ -127,6 +128,7 @@ static unsigned int FUNCTYPE
 CALC (register number_t zre, register number_t zim, register number_t pre,
       register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned
        CALC (register number_t zre, register number_t zim,
 	     register number_t pre, register number_t pim)
@@ -256,6 +258,7 @@ static unsigned int FUNCTYPE
 SCALC (register number_t zre, register number_t zim, register number_t pre,
        register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        SCALC (register number_t zre, register number_t zim,
 	      register number_t pre, register number_t pim)
@@ -264,6 +267,7 @@ static unsigned int FUNCTYPE
 CALC (register number_t zre, register number_t zim, register number_t pre,
       register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        CALC (register number_t zre, register number_t zim,
 	     register number_t pre, register number_t pim)
@@ -317,7 +321,7 @@ CALC (register number_t zre, register number_t zim, register number_t pre,
 
 /*F. : Periodicity checking rountines.          (16-02-97)
    All comments preceded by F. are mine (Fabrice Premel premelfa@etu.utc.fr).
-   Tried to make coed as efficient as possible.
+   Tried to make code as efficient as possible.
    Next to do is convert lim in a variable that would be updated sometimes
    I'll try to make here a short explanation on periodicity checking :
    first, we'll define 2 variables : whentosave and whenincsave, which are, respectively,
@@ -348,6 +352,7 @@ static unsigned int FUNCTYPE
 SPERI (register number_t zre, register number_t zim, register number_t pre,
        register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        SPERI (register number_t zre, register number_t zim,
 	      register number_t pre, register number_t pim)
@@ -356,6 +361,7 @@ static unsigned int FUNCTYPE
 PERI (register number_t zre, register number_t zim, register number_t pre,
       register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        PERI (register number_t zre, register number_t zim,
 	     register number_t pre, register number_t pim)
@@ -471,6 +477,7 @@ static unsigned int FUNCTYPE
 SPERI (register number_t zre, register number_t zim, register number_t pre,
        register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        SPERI (register number_t zre, register number_t zim,
 	      register number_t pre, register number_t pim)
@@ -479,6 +486,7 @@ static unsigned int FUNCTYPE
 PERI (register number_t zre, register number_t zim, register number_t pre,
       register number_t pim)
      CONSTF REGISTERS (3);
+REGISTERS (3)
      static unsigned int FUNCTYPE
        PERI (register number_t zre, register number_t zim,
 	     register number_t pre, register number_t pim)
