@@ -1,3 +1,4 @@
+#include <config.h>
 #ifdef _plan9_
 #include <u.h>
 #include <libc.h>
@@ -5,6 +6,9 @@
 #include <stdlib.h>
 #include <string.h>
 #endif
+#ifdef HAVE_GETTEXT
+#include <iconv.h>
+#endif
 #include <archaccel.h>
 
 #include <fconfig.h>
@@ -13,13 +17,15 @@
 #include <ui_helper.h>
 #include <grlib.h>
 
-#define WIDTH(ch) currentfont->width
-#define RWIDTH(ch) currentfont->realwidth
-#define HEIGHT currentfont->height
+#define WIDTH(ch) (currentfont->width)
+#define RWIDTH(ch) (currentfont->realwidth)
+#define HEIGHT (currentfont->height)
 #define DATA currentfont->data
 
 extern CONST unsigned char xfont8[];
 extern CONST unsigned char xfont16[];
+extern CONST unsigned char xfont32[];
+extern CONST unsigned char xfont48[];
 extern CONST unsigned char xfont14[];
 extern CONST unsigned char xfont8il1[];
 extern CONST unsigned char xfont16il1[];
@@ -40,6 +46,14 @@ CONST struct xfont xbigfont = {
   xfont16,
   9, 16, 8
 };
+CONST struct xfont xbigfont2 = {
+  xfont32,
+  18, 32, 16
+};
+CONST struct xfont xbigfont3 = {
+  xfont48,
+  18, 48, 16
+};
 CONST struct xfont xsmallfontil1 = {
   xfont8il1,
   8, 8, 8
@@ -379,12 +393,72 @@ skip (CONST char *text)
   return (i);
 }
 
+#ifdef HAVE_GETTEXT
+int
+xiconv(int encoding,
+       char *out, int *outlen,
+       const char *in, int *inlen) {
+    /* 
+     * Since the built-in text system only supports Latin-1 and Lqtin-2
+     * encodings, we must convert strings from the user's native encoding to
+     * either Latin-1 or Latin-2 encoding as appropriate for the selected 
+     * language before passing them into the built-in text system.  This
+     * function wraps the gnu iconv library for this purpose.
+     */
+    
+	iconv_t cd;
+    char tocode[16];
+	size_t icv_inlen = *inlen, icv_outlen = *outlen;
+	const char *icv_in = (const char *) in;
+	char *icv_out = (char *) out;
+	int ret;
+    
+    sprintf(tocode, "ISO-8859-%d", encoding);
+    cd = iconv_open(tocode, "UTF-8");
+    if (cd == (iconv_t)(-1))
+        return -1;
+    
+    ret = iconv(cd,
+                &icv_in, &icv_inlen,
+                &icv_out, &icv_outlen);
+    
+	if (in != NULL) {
+	    *inlen -= icv_inlen;
+	    *outlen -= icv_outlen;
+        out[*outlen] = '\0';
+	} else {
+	    *inlen = 0;
+	    *outlen = 0;
+	}
+    
+	if (icv_inlen != 0 || ret == (size_t) -1)
+        return -1;
+    
+    ret = iconv_close(cd);
+    
+    if (ret == -1)
+        return -1;
+    
+	return 0;
+}
+#endif
+
 int
 xprint (struct image *image, CONST struct xfont *current, int x, int y,
-	CONST char *text, int fgcolor, int bgcolor, int mode)
+	CONST char *text, int encoding, int fgcolor, int bgcolor, int mode)
 {
   int i = 0;
   int aacolor = 0;
+#ifdef HAVE_GETTEXT
+    char intext[BUFSIZ];
+    int inlen = strlen(text);
+    char outtext[BUFSIZ];
+    int outlen = BUFSIZ;
+    
+    strncpy(intext, text, BUFSIZ);
+    if (encoding && xiconv(encoding, outtext, &outlen, intext, &inlen) == 0)
+        text = outtext;
+#endif
   if (!text[0])
     return 0;
   /*Do some clipping */
@@ -481,7 +555,7 @@ xprint (struct image *image, CONST struct xfont *current, int x, int y,
 	      }
 	    break;
 	  }
-      x += WIDTH (*text);
+      x += WIDTH (*text) ;
       text++;
       i++;
     }
