@@ -4,10 +4,12 @@
 #define TUTORIALPATH DATAPATH"/tutorial/"
 #define EXAMPLESPATH DATAPATH"/examples/"
 #define CATALOGSPATH DATAPATH"/catalogs/"
+#define HELPPATH DATAPATH"/help/xaos.hlp"
 
 #define DEFAULT_MAX_ITER 170
 				      /*default number of iterations should be set
 				         lower for slow computers */
+#define DEFAULT_BAILOUT  4
 #define MAXSTEP		(0.008*3)
 				       /*zooming step. For slow computer should
 				          be set lower. Longer steps takes more time
@@ -22,7 +24,6 @@
 
 
 		/*some constatnts used by various parts of XaoS */
-#undef DEBUG
 #ifndef DEBUG
 #define NDEBUG
 #endif
@@ -34,7 +35,7 @@
 #define NGUESSES (RANGE1*RANGE1/2)
 #define MAXTIME 10
 				  /*maximum zooming time to one direction */
-#define NGUESSES1 40
+#define NGUESSES1 10
 				/*maximum number of guesses using first
 				   method */
 #define NGUESSES2 1000
@@ -58,4 +59,5 @@ typedef FPOINT_TYPE number_t;
 #else
 #define STAT(x)
 #endif
+#define NUMBER_BIG ((number_t)INT_MAX)
 #endif /*FCONFIG_H */
