@@ -82,7 +82,7 @@ CONST char *CONST uih_colornames[] = {
 #define MAX_MENUDIALOGS_I18N 100
 #define Register(variable) variable = & menudialogs_i18n[no_menudialogs_i18n]
 static menudialog menudialogs_i18n[MAX_MENUDIALOGS_I18N];
-static int no_menudialogs_i18n;
+//static int no_menudialogs_i18n;
 
 static menudialog *uih_perturbationdialog, *uih_juliadialog,
   *uih_smoothmorphdialog, *uih_renderdialog, *uih_viewdialog,
@@ -94,7 +94,11 @@ static menudialog *uih_perturbationdialog, *uih_juliadialog,
   *uih_filterdialog, *uih_shiftdialog, *uih_speeddialog, *printdialog,
   *uih_bailoutdialog, *saveanimdialog, *uih_juliamodedialog,
   *uih_textposdialog, *uih_fastmodedialog, *uih_timedialog,
-  *uih_numdialog, *uih_fpdialog, *palettedialog, *uih_cyclingdialog;
+  *uih_numdialog, *uih_fpdialog, *palettedialog, *uih_cyclingdialog
+#ifdef SFFE_USING
+	,*uih_sffedialog, *uih_sffeinitdialog
+#endif
+;
 
 extern char *xtextposnames[];
 extern char *ytextposnames[];
@@ -135,7 +139,7 @@ static menudialog uih_perturbationdialog[] = {
 
   Register (uih_renderdialog);
   DIALOGIFILE_I (gettext ("File to render:"), "fract*.xaf");
-  DIALOGSTR_I (gettext ("Basename:"), "anim");
+  DIALOGOFILE_I (gettext ("Basename:"), "anim");
   DIALOGINT_I (gettext ("Width:"), 640);
   DIALOGINT_I (gettext ("Height:"), 480);
   DIALOGFLOAT_I (gettext ("Real width (cm):"), 29.0);
@@ -287,6 +291,16 @@ static menudialog uih_perturbationdialog[] = {
   DIALOGINT_I (gettext ("Frames per second:"), 0);
   NULL_I ();
 
+#ifdef SFFE_USING
+  Register (uih_sffedialog);
+  DIALOGSTR_I (gettext ("Formula:"), "z^2+c");
+  NULL_I ();
+
+  Register (uih_sffeinitdialog);
+  DIALOGSTR_I (gettext ("Initialization:"), "");
+  NULL_I ();
+#endif
+
 #ifdef DEBUG
   printf ("Filled %d widgets out of %d.\n",
 	  no_menudialogs_i18n, MAX_MENUDIALOGS_I18N);
@@ -299,6 +313,10 @@ static menudialog uih_perturbationdialog[] = {
  * End of registering internationalized dialogs.
  */
 
+#ifdef SFFE_USING
+ void uih_sffein (uih_context * c, CONST char *text);
+ void uih_sffeinitin (uih_context * c, CONST char *text);
+#endif
 
 static void
 uih_smoothmorph (struct uih_context *c, dialogparam * p)
@@ -329,7 +347,20 @@ uih_smoothmorph (struct uih_context *c, dialogparam * p)
 static void
 uih_render (struct uih_context *c, dialogparam * d)
 {
-  if (d[2].dint <= 0 || d[2].dint > 4096)
+#ifdef MACOSX
+    /* 
+     * On Mac OS X, we must ensure basename specifies an absolute path in order
+     * to prevent png files from being rendered to the root directory.
+     */
+    if (d[1].dstring[0] != '/' )
+    {
+        uih_error (c,
+                   gettext
+                   ("renderanim: Must specify a valid absolute path for basename"));
+        return;
+    }
+#endif
+    if (d[2].dint <= 0 || d[2].dint > 4096)
     {
       uih_error (c,
 		 gettext
@@ -755,11 +786,21 @@ uih_cyclingselected (struct uih_context *c)
 {
   if (c == NULL)
     return 0;
-  return (c->cycling);
+ return (c->cycling && c->cyclingdirection==1);
+}	 
+static int	 
+uih_rcyclingselected (struct uih_context *c)	 
+{	 
+        if (c == NULL)	 
+                return 0;	 
+        return (c->cycling && c->cyclingdirection==-1);
 }
 static void
 uih_cyclingsw (struct uih_context *c)
 {
+ // Andrew Stone: this fixes what I consider a bug - switching from Y to y should keep cycling:	 
+  if (c->cycling && c->cyclingdirection == -1) 
+	uih_cycling_off (c);
   c->cyclingdirection = 1;
   if (c->cycling)
     uih_cycling_off (c);
@@ -770,6 +811,9 @@ uih_cyclingsw (struct uih_context *c)
 static void
 uih_rcyclingsw (struct uih_context *c)
 {
+  // Andrew Stone: this fixes what I consider a bug - switching from y to Y should keep cycling:	 
+  if (c->cycling && c->cyclingdirection == 1) 
+	uih_cycling_off (c);
   c->cyclingdirection = -1;
   if (c->cycling)
     uih_cycling_off (c);
@@ -835,7 +879,7 @@ uih_persw (struct uih_context *c, number_t x, number_t y)
     uih_setperbutation (c, 0.0, 0.0);
   else
     uih_setperbutation (c, x, y);
-  printf(""); // fixme: some newer versions of gcc crashes without this
+  // printf(""); // fixme: some newer versions of gcc crashes without this
 }
 static int
 uih_perselected (struct uih_context *c)
@@ -916,9 +960,21 @@ static CONST menuitem *menuitems;	/*XaoS menu specifications */
 
 
 /* Registering internationalized menus. See also include/xmenu.h
-   for details. Note that MAX_MENUITEMS_I18N may be increased
-   if more items will be added in future. */
-#define MAX_MENUITEMS_I18N 200
+   for details. Note that MAX_MENUITEMS_I18N should be increased
+   if more items will be added in future.
+   
+   On 2006-07-12 J.B. Langston wrote:
+   
+   The menu.c.diff file changes the MAX_MENUITEMS_I18N macro from
+   200 to 250.  As of 3.2.1, the number of allocated menu items had 
+   been exceeded (there are 201 menu items now). This was causing
+   the memory within the application to be clobbered, resulting 
+   in subtle bugs on the PowerPC platform (both X11 and OSX drivers).
+   For example, rendering animations generated a segmentation fault.
+   It's quite possible it could have been causing other subtle bugs
+   elsewhere in the program. */
+
+#define MAX_MENUITEMS_I18N 250
 static menuitem menuitems_i18n[MAX_MENUITEMS_I18N];
 int uih_no_menuitems_i18n;
 
@@ -1035,14 +1091,25 @@ uih_registermenus_i18n (void)
   SUBMENU_I ("root", "e", gettext ("Filters"), "mfilter");
   SUBMENU_I ("root", NULL, gettext ("UI"), "ui");
   SUBMENU_I ("root", NULL, gettext ("Misc"), "misc");
+#ifdef MACOSX
+  SUBMENU_I ("root", NULL, gettext ("Window"), "window");
+#endif
   SUBMENU_I ("root", NULL, gettext ("Help"), "helpmenu");
   SUBMENU_I ("helpmenu", NULL, gettext ("Tutorials"),
 	     "tutor") SUBMENUNOOPT_I ("animroot", "f", gettext ("File"),
-				      "file");
+ 				      "file");
+#ifdef MACOSX
+  // You cannot have menu items directly on the root menu in Mac OS X
+  // So we put the "Stop Replay" item in the UI menu instead
+  MENUSEPARATOR_I ("uia");
+  MENUNOP_I ("uia", "s", gettext ("Stop replay"), "stopreplay",
+	     UI | MENUFLAG_INTERRUPT, uih_replaydisable);
+#else
   MENUNOP_I ("animroot", "s", gettext ("Stop replay"), "stopreplay",
 	     UI | MENUFLAG_INTERRUPT, uih_replaydisable);
-  SUBMENUNOOPT_I ("animroot", NULL, gettext ("Help"), "helpmenu");
+#endif
   SUBMENUNOOPT_I ("animroot", NULL, gettext ("UI"), "uia");
+  SUBMENUNOOPT_I ("animroot", NULL, gettext ("Help"), "helpmenu");
   MENUDIALOG_I ("misc", "!", gettext ("Command"), "command", UI, uih_command,
 		dcommand);
   MENUDIALOG_I ("misc", NULL, gettext ("Play string"), "playstr",
@@ -1109,7 +1176,9 @@ uih_registermenus_i18n (void)
 	     MENUFLAG_INTERRUPT, uih_loadexample);
   MENUNOP_I ("file", NULL,
 	     gettext ("Save configuration"), "savecfg", 0, uih_savecfg);
+#ifndef MACOSX
   MENUSEPARATOR_I ("file");
+#endif
   MENUNOP_I ("edit", "u", gettext ("Undo"), "undo",
 	     MENUFLAG_INTERRUPT | MENUFLAG_NOPLAY |
 	     MENUFLAG_NOOPTION, uih_undo);
@@ -1120,6 +1189,14 @@ uih_registermenus_i18n (void)
 	     | MENUFLAG_NOPLAY | MENUFLAG_NOOPTION, uih_redo);
   SUBMENU_I ("fractal", NULL, gettext ("Formulae"), "mformula");
   SUBMENU_I ("fractal", NULL, gettext ("More formulae"), "oformula");
+
+#ifdef SFFE_USING
+  /*FIXME: Should allow multiline */
+  MENUSEPARATOR_I ("fractal");
+  MENUDIALOG_I ("fractal", NULL, gettext ("User formula"), "usrform", 0, uih_sffein, uih_sffedialog);	
+  MENUDIALOG_I ("fractal", NULL, gettext ("User initialization"), "usrformInit", 0, uih_sffeinitin, uih_sffeinitdialog);	
+#endif
+
   MENUSEPARATOR_I ("fractal");
   SUBMENU_I ("fractal", "f", gettext ("Incoloring mode"), "mincoloring");
   SUBMENU_I ("fractal", "c", gettext ("Outcoloring mode"), "moutcoloring");
@@ -1200,7 +1277,7 @@ uih_registermenus_i18n (void)
 	       "cycling", 0, uih_cyclingsw, uih_cyclingselected);
   MENUNOPCB_I ("palettemenu", "Y", gettext ("Reversed color cycling"),
 	       "rcycling", MENUFLAG_NOOPTION | MENUFLAG_NOPLAY,
-	       uih_rcyclingsw, uih_cyclingselected);
+	       uih_rcyclingsw, uih_rcyclingselected);
   MENUCDIALOG_I ("palettemenu", NULL,
 		 gettext
 		 ("Color cycling speed"),
@@ -1269,6 +1346,10 @@ uih_registermenus_i18n (void)
 	       gettext ("Autopilot"),
 	       "autopilot", 0, uih_autopilotsw, uih_autopilotselected);
   MENUSEPARATOR_I ("ui");
+  MENUNOPCB_I ("ui", "v",	 
+              gettext ("VJ mode"),	 
+              "inhibittextoutput", 0, uih_inhibittextsw, uih_inhibittextselected);
+  MENUSEPARATOR_I ("ui");
   MENUNOP_I ("ui", "r", gettext ("Recalculate"),
 	     "recalculate", 0, uih_recalculate);
   MENUNOP_I ("ui", "z",
@@ -1562,3 +1643,76 @@ uih_unregistermenus (void)
 
   menu_delete (menuitems2, NITEMS (menuitems2));
 }
+
+#ifdef SFFE_USING
+void
+uih_sffein (uih_context * c, CONST char *text)
+{
+ char str[200]; 
+ int err;
+ if ( strlen(text) )
+ {
+  c->parser->errormsg = (char*)str;
+	if ( (err=sffe_parse( &c->parser, (char*)text ))> 0 )
+	{
+		uih_message (c, str);
+		sffe_parse( &c->parser, "z^2+c");
+		uih_sffedialog->defstr = c->parser->expression;		
+	} else 
+	     {  
+		uih_sffedialog->defstr = c->parser->expression;
+		uih_message( c, c->parser->expression );
+			if ( !(c->fcontext->currentformula->flags&SFFE_FRACTAL) )
+			{
+				uih_setformula(c,24);
+				//uih_newimage(c);
+			} else uih_recalculate(c);
+	     };
+
+  c->parser->errormsg = NULL;
+ };
+};
+
+void
+uih_sffeinitin (uih_context * c, CONST char *text)
+{
+ extern cmplx pZ;
+ extern cmplx C;
+ char str[200]; 
+ int err;
+ uih_sffeinitdialog->defstr = "";
+  if ( strlen(text) )
+  {
+	if ( !c->pinit )
+	{
+		c->pinit = sffe_alloc();
+ 		sffe_regvar( &c->pinit, &pZ, 'p' );
+ 		sffe_regvar( &c->pinit, &C, 'c');
+	};
+
+    c->pinit->errormsg = (char*)str;
+        if ( (err=sffe_parse( &c->pinit, (char*)text ))>0 )
+	{ 
+		uih_message (c,str);
+		sffe_free(&c->pinit); 
+		c->pinit=NULL; 
+	} else 
+		{
+			uih_sffeinitdialog->defstr = c->pinit->expression; /*FIXME shouldnt this be done by str copy */
+			uih_message( c, c->pinit->expression );
+				if ( !(c->fcontext->currentformula->flags&SFFE_FRACTAL) )
+				{
+					uih_setformula(c,24);
+					//uih_newimage(c);
+				} else uih_recalculate(c);
+			c->pinit->errormsg = NULL;
+		};
+
+  } else if ( c->pinit ) 
+	  { 
+		sffe_free(&c->pinit); 
+		c->pinit=NULL; 
+		uih_recalculate(c);
+ 	  };
+};
+#endif
