@@ -23,9 +23,10 @@
 #include <config.h>
 #include <ui.h>
 extern CONST struct ui_driver svga_driver, x11_driver, dog_driver,
-  plan9_driver, plan9_driver, mac_driver, mac_full_driver, os2vio_driver,
-  be_driver, be_direct_driver, be_screen_driver, aalib_driver, ggi_driver,
-  win32_driver, dxw_driver, dxf_driver, DGA_driver;
+  plan9_driver, plan9_driver, mac_driver, mac_full_driver, osx_driver, 
+  osx_fullscreen_driver, os2vio_driver, cocoa_driver, cocoa_fullscreen_driver,
+  be_driver, be_direct_driver, be_screen_driver, aalib_driver, gtk_driver, 
+  ggi_driver, win32_driver, dxw_driver, dxf_driver, DGA_driver;
 CONST struct ui_driver *CONST drivers[] = {
 #ifdef WIN32_DRIVER
   &win32_driver,
@@ -43,6 +44,9 @@ CONST struct ui_driver *CONST drivers[] = {
 #ifdef DGA_DRIVER
   &DGA_driver,
 #endif
+#ifdef GTK_DRIVER
+  &gtk_driver,
+#endif
 #ifdef GGI_DRIVER
   &ggi_driver,
 #endif
@@ -62,6 +66,14 @@ CONST struct ui_driver *CONST drivers[] = {
   &mac_driver,
   &mac_full_driver,
 #endif
+#ifdef OSX_DRIVER
+  &osx_driver,
+  &osx_fullscreen_driver,
+#endif
+#ifdef COCOA_DRIVER
+  &cocoa_driver,
+  &cocoa_fullscreen_driver,
+#endif
 #ifdef BEOS_DRIVER
   &be_driver,
   &be_direct_driver,
