@@ -72,6 +72,10 @@
 #define gettext(STRING) STRING
 #endif
 
+#ifdef SFFE_USING
+	#include "sffe.h"
+#endif
+
 #ifdef DESTICKY
 int euid, egid;
 #endif
@@ -103,6 +107,7 @@ main_loop (void)
   NORETURN;
 
      int prog_argc;
+     int err;
      char **prog_argv;
 /*UI state */
      uih_context *uih;
@@ -137,6 +142,12 @@ main_loop (void)
      static int maxframerate = 80;
      static float defscreenwidth = 0.0, defscreenheight = 0.0, defpixelwidth =
        0.0, defpixelheight = 0.0;
+
+#ifdef SFFE_USING
+     char *sffeform = NULL;
+     char *sffeinit = NULL;
+#endif
+
      CONST struct params global_params[] = {
        {"-delay", P_NUMBER, &delaytime,
 	"Delay screen updates (milliseconds)"},
@@ -173,6 +184,12 @@ main_loop (void)
 	"exact size of one pixel in centimeters"},
        {"-pixelheight", P_FLOAT, &defpixelheight,
 	"exact size of one pixel in centimeters"},
+#ifdef SFFE_USING
+       {"-formula", P_STRING, &sffeform,
+	"user formula"},
+       {"-forminit", P_STRING, &sffeinit,
+	"z0 for user formula"},
+#endif
        {NULL, 0, NULL, NULL}
      };
 
@@ -452,52 +469,58 @@ ui_drawstatus (uih_context * uih, void *data)
   int h = xtextheight (uih->font);
   sprintf (str, gettext ("Fractal name:%s"),
 	   uih->fcontext->currentformula->name[!uih->fcontext->mandelbrot]);
-  xprint (uih->image, uih->font, 0, statusstart, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("Fractal type:%s"),
 	   uih->fcontext->
 	   mandelbrot ? gettext ("Mandelbrot") : gettext ("Julia"));
-  xprint (uih->image, uih->font, 0, statusstart + h, str, FGCOLOR (uih),
+#ifdef SFFE_USING
+  if ( uih->fcontext->currentformula->flags&SFFE_FRACTAL )
+  {
+  	sprintf (str, gettext ("Formula:%s"),uih->parser->expression);
+  }; 
+#endif
+  xprint (uih->image, uih->font, 0, statusstart + h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("View:[%1.12f,%1.12f]"),
 	   (double) uih->fcontext->s.cr, (double) uih->fcontext->s.ci);
-  xprint (uih->image, uih->font, 0, statusstart + 2 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 2 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("size:[%1.12f,%1.12f]"),
 	   (double) uih->fcontext->s.rr, (double) uih->fcontext->s.ri);
-  xprint (uih->image, uih->font, 0, statusstart + 3 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 3 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("Rotation:%4.2f   Screen size:%i:%i"),
 	   (double) uih->fcontext->angle, uih->image->width,
 	   uih->image->height);
-  xprint (uih->image, uih->font, 0, statusstart + 4 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 4 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("Iterations:%-4i Palette size:%i"),
 	   uih->fcontext->maxiter, uih->image->palette->size);
-  xprint (uih->image, uih->font, 0, statusstart + 5 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 5 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, "Bailout:%4.2f", (double) uih->fcontext->bailout);
-  xprint (uih->image, uih->font, 0, statusstart + 6 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 6 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("Autopilot:%-4s  Plane:%s"),
 	   uih->autopilot ? gettext ("On") : gettext ("Off"),
 	   planename[uih->fcontext->plane]);
-  xprint (uih->image, uih->font, 0, statusstart + 7 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 7 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("incoloring:%s    outcoloring:%s"),
 	   incolorname[uih->fcontext->incoloringmode],
 	   outcolorname[uih->fcontext->coloringmode]);
-  xprint (uih->image, uih->font, 0, statusstart + 8 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 8 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   sprintf (str, gettext ("zoomspeed:%f"), (float) uih->maxstep * 1000);
-  xprint (uih->image, uih->font, 0, statusstart + 9 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 9 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
   if (uih->fcontext->mandelbrot)
     strcpy (str, gettext ("Parameter:none"));
   else
     sprintf (str, gettext ("Parameter:[%f,%f]"), (float) uih->fcontext->pre,
 	     (float) uih->fcontext->pim);
-  xprint (uih->image, uih->font, 0, statusstart + 10 * h, str, FGCOLOR (uih),
+  xprint (uih->image, uih->font, 0, statusstart + 10 * h, str, uih->encoding, FGCOLOR (uih),
 	  BGCOLOR (uih), 0);
 #ifdef MEMCHECK
   {
@@ -548,7 +571,7 @@ ui_ministatuspos (uih_context * uih, int *x, int *y, int *w, int *h,
 static void
 ui_drawministatus (uih_context * uih, void *data)
 {
-  xprint (uih->image, uih->font, 0, ministatusstart, statustext,
+  xprint (uih->image, uih->font, 0, ministatusstart, statustext, uih->encoding,
 	  FGCOLOR (uih), BGCOLOR (uih), 0);
 }
 static void
@@ -1036,11 +1059,13 @@ static void
 ui_registermenus_i18n (void)
 {
   int no_menuitems_i18n = ui_no_menuitems_i18n;	/* This variable must be local. */
+#ifndef MACOSX
   SUBMENU_I ("file", "q", gettext ("Quit"), "quitmenu");
   MENUINT_I ("quitmenu", NULL, gettext ("Exit now"), "quit",
 	     MENUFLAG_INTERRUPT | MENUFLAG_ATSTARTUP, ui_quitwr, 1);
   MENUINT_I ("quitmenu", NULL, gettext ("Not yet"), "noquit", UI, ui_quitwr,
 	     0);
+#endif
   MENUNOP_I ("helpmenu", "h", gettext ("Help"), "help", MENUFLAG_INCALC,
 	     ui_helpwr);
   MENUNOPCB_I ("ui", NULL, gettext ("Disable XaoS's builtin GUI"), "nogui",
@@ -1098,6 +1123,12 @@ ui_unregistermenus (void)
 }
 
 int number_six = 6;
+
+#ifdef SFFE_USING
+	/* parser variables vars */
+	cmplx Z,C,pZ;
+#endif
+
 #define MAX_WELCOME 50
 #ifndef MAIN_FUNCTION
 #define MAIN_FUNCTION main
@@ -1149,6 +1180,10 @@ MAIN_FUNCTION (int argc, char **argv)
 	strcpy (language, "espanhol");
       if (strncmp (locale, "French", 6) == 0)
 	strcpy (language, "francais");
+      if (strncmp (locale, "Romanian", 8) == 0)
+	strcpy (language, "romanian");
+      if (strncmp (locale, "Italian", 7) == 0)
+	strcpy (language, "italiano");
     }
   // x_message("%s",language);
 #else
@@ -1176,6 +1211,10 @@ MAIN_FUNCTION (int argc, char **argv)
 	strcpy (language, "espanhol");
       if (strcmp (locale, "fr") == 0)
 	strcpy (language, "francais");
+      if (strcmp (locale, "ro") == 0)
+	strcpy (language, "romanian");
+      if (strcmp (locale, "it") == 0)
+	strcpy (language, "italiano");
     }
 #endif
 #ifdef DEBUG
@@ -1201,13 +1240,18 @@ MAIN_FUNCTION (int argc, char **argv)
     )
 #endif
 #else
-			  "/usr/share/locale")
+#ifdef USE_LOCALEPATH
+    localepath)
+#else
+    "/usr/share/locale")
+#endif
 #ifdef DEBUG
     )
 #endif
 #endif
 #endif
     ;
+  bind_textdomain_codeset ("xaos", "UTF-8");
   textdomain ("xaos");
   /* Done setting locales. */
 #endif
@@ -1378,7 +1422,7 @@ MAIN_FUNCTION (int argc, char **argv)
 
   driver->print (0, textheight1 * 2, "Initializing fractal engine");
   ui_flush ();
-  uih =
+  globaluih = uih =
     uih_mkcontext (driver->flags, image, ui_passfunc, ui_message,
 		   ui_updatemenus);
   if (driver->gui_driver && driver->gui_driver->setrootmenu)
@@ -1455,7 +1499,7 @@ MAIN_FUNCTION (int argc, char **argv)
       }
   }
 #ifndef _plan9_
-  sprintf (welcome, gettext ("Welcome to XaoS version %s"), XaoS_VERSION);
+  sprintf (welcome, gettext ("Welcome to XaoS version %s"), XaoS_VERSION); /*TYPE*/
   uih_message (uih, welcome);
 #endif
   uih_updatemenus (uih, driver->name);
@@ -1570,10 +1614,28 @@ MAIN_FUNCTION (int argc, char **argv)
       x_message ("Approximation loop speed: %g FPS", c / 5.0);
       ui_doquit (0);
     }
+
+#ifdef SFFE_USING
+ /*SFFE : malczak */
+	if ( sffeform ) err = sffe_parse( &uih->parser, (char*)sffeform ); else
+   		sffe_parse( &uih->parser, "z^2+c");
+	if ( sffeinit )
+	{
+		uih->pinit = sffe_alloc();
+		sffe_regvar( &uih->pinit, &pZ, 'p' );
+		sffe_regvar( &uih->pinit, &C, 'c');
+		if ( sffe_parse( &uih->pinit, (char*)sffeinit )>0 ) sffe_free(&uih->pinit);
+		 
+	};
+    if (err>0) sffe_parse( &uih->parser, "z^2+c");
+ /*SFFE*/
+#endif
+
   driver->print (0, textheight1 * 8, "Entering main loop");
   ui_flush ();
   main_loop ();
   ui_quit ();
+
   return (0);
 }
 
@@ -1748,7 +1810,7 @@ main_loop (void)
   driver->processevents ((!inmovement && !uih->inanimation), &x, &y, &b, &k);
   while (1)
     {
-      mousetype (uih->play ? REPLAYMOUSE : NORMALMOUSE);
+        mousetype (uih->play ? REPLAYMOUSE : uih->inhibittextoutput ? VJMOUSE: NORMALMOUSE);
       if (uih->display)
 	{
 	  uih_prepare_image (uih);
